# Example usage of the mhqol_LSS function
# Get the LSS based on a character vector and calculate the total LSS,
# not all dimensions are present
mhqol_LSS(
dimensions = c(IN = 2, MO = 3, RE = 2, DA = 1, PH = 2, FU = 3),
metric = "total", ignore_invalid = TRUE)
# Get the LSS based on a dataframe and calculate the average LSS,
# all dimensions are present
mhqol_LSS(
dimensions =
data.frame(SI = 1, IN = 2, MO = 3, RE = 2, DA = 1, PH = 2, FU = 3),
metric = "average")
Run the code above in your browser using DataLab