Learn R Programming

MHQoL (version 0.14.0)

mhqol_utilities_to_states: Provides the states of the MHQoL based on the utilities provided (as described in the valueset)

Description

This function provides the states of the MHQoL based on the utilities provided (as described in the valueset).

Usage

mhqol_utilities_to_states(
  utilities,
  country = "Netherlands",
  ignore_invalid = FALSE,
  ignore_NA = FALSE,
  retain_old_variables = TRUE)

Value

A dataframe containing the states of the MHQoL based on the utilities provided.

Arguments

utilities

A dataframe, numeric vector, or list containing the utilities of the MHQoL.

country

The country for which the utilities should be calculated. For now the only option is "Netherlands".

ignore_invalid

If TRUE, the function will ignore missing utilities and continue processing.

ignore_NA

If TRUE, the function will ignore NA values in the input data.

retain_old_variables

If TRUE, the function will retain the old variables in the output.

Examples

Run this code
# Example usage of the mhqol_utilities_to_states function
# Get the states based on a numeric vector, not all states are present
mhqol_utilities_to_states(
  utilities = c(IN = -0.018, DA = -0.021, PH = -0.064, FU = -0.106),
  ignore_invalid = TRUE
)

# Get the states based on a dataframe
mhqol_utilities_to_states(
  utilities = data.frame(
    SI = -0.137,
    IN = -0.184,
    MO = -0.063,
    RE = -0.172,
    DA = -0.021,
    PH = -0.243,
    FU = -0.170
    )
)

Run the code above in your browser using DataLab