Learn R Programming

MHQoL (version 0.14.0)

shiny_mhqol: Launch Shiny MHQoL Interface

Description

shiny_mhqol launches a Shiny interface for browser-based MHQoL calculations.

Usage

shiny_mhqol(display.mode = "normal")

Value

NULL (launches the Shiny app).

Arguments

display.mode

The display mode to be passed to runApp. Default is "normal".

Details

This function starts the Shiny app for Mental Health Quality of Life (MHQoL) scoring, allowing users to interactively input data and calculate utility scores.

Examples

Run this code
if(interactive()) {
  shiny_mhqol()
  shiny_mhqol(display.mode = "normal")
}

Run the code above in your browser using DataLab